@@ -1,3 +1,8 @@
+"""
+Functions for reading and manipulating SRM tables.
+
+(c) Oscar Branson : https://github.com/oscarbranson
+"""
 import numpy as np
 import pandas as pd
 
@@ -17,7 +22,7 @@ def read_table(srm_file):
     -------
     SRM compositions : pandas.DataFrame
     """
-    return pd.read_csv(srm_file).set_index('SRM')
+    return pd.read_csv(srm_file).set_index('SRM').dropna(how='all')
 
 def get_defined_srms(srm_file):
     """
